@@ -1,6 +1,6 @@
 """Version information for mcp-ticketer package."""
 
-__version__ = "0.3.7"
+__version__ = "0.13.2"
 __version_info__ = tuple(int(part) for part in __version__.split("."))
 
 # Package metadata
@@ -27,7 +27,7 @@ __features__ = {
 }
 
 
-def get_version():
+def get_version() -> str:
     """Return the full version string with build metadata if available."""
     version = __version__
     if __build__:
@@ -37,6 +37,6 @@ def get_version():
     return version
 
 
-def get_user_agent():
+def get_user_agent() -> str:
     """Return a user agent string for API requests."""
     return f"{__title__}/{__version__}"
