@@ -47,29 +47,29 @@ class AdapterConfig:
     enabled: bool = True
 
     # Common fields (not all adapters use all fields)
-    api_key: Optional[str] = None
-    token: Optional[str] = None
+    api_key: str | None = None
+    token: str | None = None
 
     # Linear-specific
-    team_id: Optional[str] = None
-    team_key: Optional[str] = None
-    workspace: Optional[str] = None
+    team_id: str | None = None
+    team_key: str | None = None
+    workspace: str | None = None
 
     # JIRA-specific
-    server: Optional[str] = None
-    email: Optional[str] = None
-    api_token: Optional[str] = None
-    project_key: Optional[str] = None
+    server: str | None = None
+    email: str | None = None
+    api_token: str | None = None
+    project_key: str | None = None
 
     # GitHub-specific
-    owner: Optional[str] = None
-    repo: Optional[str] = None
+    owner: str | None = None
+    repo: str | None = None
 
     # AITrackdown-specific
-    base_path: Optional[str] = None
+    base_path: str | None = None
 
     # Project ID (can be used by any adapter for scoping)
-    project_id: Optional[str] = None
+    project_id: str | None = None
 
     # Additional adapter-specific configuration
     additional_config: dict[str, Any] = field(default_factory=dict)
@@ -126,9 +126,9 @@ class ProjectConfig:
     """Configuration for a specific project."""
 
     adapter: str
-    api_key: Optional[str] = None
-    project_id: Optional[str] = None
-    team_id: Optional[str] = None
+    api_key: str | None = None
+    project_id: str | None = None
+    team_id: str | None = None
     additional_config: dict[str, Any] = field(default_factory=dict)
 
     def to_dict(self) -> dict[str, Any]:
@@ -147,7 +147,7 @@ class HybridConfig:
 
     enabled: bool = False
     adapters: list[str] = field(default_factory=list)
-    primary_adapter: Optional[str] = None
+    primary_adapter: str | None = None
     sync_strategy: SyncStrategy = SyncStrategy.PRIMARY_SOURCE
 
     def to_dict(self) -> dict[str, Any]:
@@ -172,11 +172,17 @@ class TicketerConfig:
     default_adapter: str = "aitrackdown"
     project_configs: dict[str, ProjectConfig] = field(default_factory=dict)
     adapters: dict[str, AdapterConfig] = field(default_factory=dict)
-    hybrid_mode: Optional[HybridConfig] = None
+    hybrid_mode: HybridConfig | None = None
+
+    # Default values for ticket operations
+    default_user: str | None = None  # Default assignee (user_id or email)
+    default_project: str | None = None  # Default project/epic ID
+    default_epic: str | None = None  # Alias for default_project (backward compat)
+    default_tags: list[str] | None = None  # Default tags for new tickets
 
     def to_dict(self) -> dict[str, Any]:
         """Convert to dictionary for JSON serialization."""
-        return {
+        result = {
             "default_adapter": self.default_adapter,
             "project_configs": {
                 path: config.to_dict() for path, config in self.project_configs.items()
@@ -186,6 +192,16 @@ class TicketerConfig:
             },
             "hybrid_mode": self.hybrid_mode.to_dict() if self.hybrid_mode else None,
         }
+        # Add optional fields if set
+        if self.default_user is not None:
+            result["default_user"] = self.default_user
+        if self.default_project is not None:
+            result["default_project"] = self.default_project
+        if self.default_epic is not None:
+            result["default_epic"] = self.default_epic
+        if self.default_tags is not None:
+            result["default_tags"] = self.default_tags
+        return result
 
     @classmethod
     def from_dict(cls, data: dict[str, Any]) -> "TicketerConfig":
@@ -212,6 +228,10 @@ class TicketerConfig:
             project_configs=project_configs,
             adapters=adapters,
             hybrid_mode=hybrid_mode,
+            default_user=data.get("default_user"),
+            default_project=data.get("default_project"),
+            default_epic=data.get("default_epic"),
+            default_tags=data.get("default_tags"),
         )
 
 
@@ -219,29 +239,77 @@ class ConfigValidator:
     """Validate adapter configurations."""
 
     @staticmethod
-    def validate_linear_config(config: dict[str, Any]) -> tuple[bool, Optional[str]]:
+    def validate_linear_config(config: dict[str, Any]) -> tuple[bool, str | None]:
         """Validate Linear adapter configuration.
 
+        Args:
+            config: Linear configuration dictionary
+
         Returns:
             Tuple of (is_valid, error_message)
 
         """
-        required = ["api_key"]
-        for field in required:
-            if field not in config or not config[field]:
-                return False, f"Linear config missing required field: {field}"
+        import logging
+        import re
 
-        # Require either team_key or team_id (team_id is preferred)
-        if not config.get("team_key") and not config.get("team_id"):
+        logger = logging.getLogger(__name__)
+
+        required = ["api_key"]
+        missing_fields = []
+
+        for field_name in required:
+            if field_name not in config or not config[field_name]:
+                missing_fields.append(field_name)
+
+        if missing_fields:
             return (
                 False,
-                "Linear config requires either team_key (short key like 'BTA') or team_id (UUID)",
+                f"Linear config missing required fields: {', '.join(missing_fields)}",
             )
 
+        # Require either team_key or team_id (team_key is preferred)
+        has_team_key = config.get("team_key") and config["team_key"].strip()
+        has_team_id = config.get("team_id") and config["team_id"].strip()
+
+        if not has_team_key and not has_team_id:
+            return (
+                False,
+                "Linear config requires either team_key (short key like 'ENG') or team_id (UUID)",
+            )
+
+        # Validate team_id format if provided (should be UUID)
+        if has_team_id:
+            team_id = config["team_id"]
+            uuid_pattern = re.compile(
+                r"^[0-9a-f]{8}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{12}$",
+                re.IGNORECASE,
+            )
+
+            if not uuid_pattern.match(team_id):
+                # Not a UUID - could be a team_key mistakenly stored as team_id
+                logger.warning(
+                    f"team_id '{team_id}' is not a UUID format. "
+                    f"It will be treated as team_key and resolved at runtime."
+                )
+                # Move it to team_key if team_key is empty
+                if not has_team_key:
+                    config["team_key"] = team_id
+                    del config["team_id"]
+                    logger.info(f"Moved non-UUID team_id to team_key: {team_id}")
+
+        # Validate user_email format if provided
+        if config.get("user_email"):
+            email = config["user_email"]
+            email_pattern = re.compile(
+                r"^[a-zA-Z0-9._%+-]+@[a-zA-Z0-9.-]+\.[a-zA-Z]{2,}$"
+            )
+            if not email_pattern.match(email):
+                return False, f"Invalid email format for user_email: {email}"
+
         return True, None
 
     @staticmethod
-    def validate_github_config(config: dict[str, Any]) -> tuple[bool, Optional[str]]:
+    def validate_github_config(config: dict[str, Any]) -> tuple[bool, str | None]:
         """Validate GitHub adapter configuration.
 
         Returns:
@@ -263,14 +331,14 @@ class ConfigValidator:
 
         # Otherwise need explicit owner and repo
         required = ["owner", "repo"]
-        for field in required:
-            if field not in config or not config[field]:
-                return False, f"GitHub config missing required field: {field}"
+        for field_name in required:
+            if field_name not in config or not config[field_name]:
+                return False, f"GitHub config missing required field: {field_name}"
 
         return True, None
 
     @staticmethod
-    def validate_jira_config(config: dict[str, Any]) -> tuple[bool, Optional[str]]:
+    def validate_jira_config(config: dict[str, Any]) -> tuple[bool, str | None]:
         """Validate JIRA adapter configuration.
 
         Returns:
@@ -278,9 +346,9 @@ class ConfigValidator:
 
         """
         required = ["server", "email", "api_token"]
-        for field in required:
-            if field not in config or not config[field]:
-                return False, f"JIRA config missing required field: {field}"
+        for field_name in required:
+            if field_name not in config or not config[field_name]:
+                return False, f"JIRA config missing required field: {field_name}"
 
         # Validate server URL format
         server = config["server"]
@@ -292,7 +360,7 @@ class ConfigValidator:
     @staticmethod
     def validate_aitrackdown_config(
         config: dict[str, Any],
-    ) -> tuple[bool, Optional[str]]:
+    ) -> tuple[bool, str | None]:
         """Validate AITrackdown adapter configuration.
 
         Returns:
@@ -306,7 +374,7 @@ class ConfigValidator:
     @classmethod
     def validate(
         cls, adapter_type: str, config: dict[str, Any]
-    ) -> tuple[bool, Optional[str]]:
+    ) -> tuple[bool, str | None]:
         """Validate configuration for any adapter type.
 
         Args:
@@ -350,7 +418,7 @@ class ConfigResolver:
     PROJECT_CONFIG_SUBPATH = ".mcp-ticketer" / Path("config.json")
 
     def __init__(
-        self, project_path: Optional[Path] = None, enable_env_discovery: bool = True
+        self, project_path: Path | None = None, enable_env_discovery: bool = True
     ):
         """Initialize config resolver.
 
@@ -361,8 +429,8 @@ class ConfigResolver:
         """
         self.project_path = project_path or Path.cwd()
         self.enable_env_discovery = enable_env_discovery
-        self._project_config: Optional[TicketerConfig] = None
-        self._discovered_config: Optional[DiscoveryResult] = None
+        self._project_config: TicketerConfig | None = None
+        self._discovered_config: DiscoveryResult | None = None
 
     def load_global_config(self) -> TicketerConfig:
         """Load default configuration (global config loading removed for security).
@@ -382,8 +450,8 @@ class ConfigResolver:
         return default_config
 
     def load_project_config(
-        self, project_path: Optional[Path] = None
-    ) -> Optional[TicketerConfig]:
+        self, project_path: Path | None = None
+    ) -> TicketerConfig | None:
         """Load project-specific configuration.
 
         Args:
@@ -424,7 +492,7 @@ class ConfigResolver:
         self.save_project_config(config)
 
     def save_project_config(
-        self, config: TicketerConfig, project_path: Optional[Path] = None
+        self, config: TicketerConfig, project_path: Path | None = None
     ) -> None:
         """Save project-specific configuration.
 
@@ -461,8 +529,8 @@ class ConfigResolver:
 
     def resolve_adapter_config(
         self,
-        adapter_name: Optional[str] = None,
-        cli_overrides: Optional[dict[str, Any]] = None,
+        adapter_name: str | None = None,
+        cli_overrides: dict[str, Any] | None = None,
     ) -> dict[str, Any]:
         """Resolve adapter configuration with hierarchical precedence.
 
@@ -582,6 +650,12 @@ class ConfigResolver:
                 overrides["team_id"] = os.getenv("MCP_TICKETER_LINEAR_TEAM_ID")
             if os.getenv("LINEAR_API_KEY"):
                 overrides["api_key"] = os.getenv("LINEAR_API_KEY")
+            if os.getenv("LINEAR_TEAM_ID"):
+                overrides["team_id"] = os.getenv("LINEAR_TEAM_ID")
+            if os.getenv("LINEAR_TEAM_KEY"):
+                overrides["team_key"] = os.getenv("LINEAR_TEAM_KEY")
+            if os.getenv("MCP_TICKETER_LINEAR_TEAM_KEY"):
+                overrides["team_key"] = os.getenv("MCP_TICKETER_LINEAR_TEAM_KEY")
 
         elif adapter_type == AdapterType.GITHUB.value:
             if os.getenv("MCP_TICKETER_GITHUB_TOKEN"):
@@ -623,7 +697,7 @@ class ConfigResolver:
 
         return overrides
 
-    def get_hybrid_config(self) -> Optional[HybridConfig]:
+    def get_hybrid_config(self) -> HybridConfig | None:
         """Get hybrid mode configuration if enabled.
 
         Returns:
@@ -655,10 +729,10 @@ class ConfigResolver:
 
 
 # Singleton instance for global access
-_default_resolver: Optional[ConfigResolver] = None
+_default_resolver: ConfigResolver | None = None
 
 
-def get_config_resolver(project_path: Optional[Path] = None) -> ConfigResolver:
+def get_config_resolver(project_path: Path | None = None) -> ConfigResolver:
     """Get the global config resolver instance.
 
     Args:
