@@ -18,6 +18,9 @@ from mcp_ticketer.core.models import (
     TicketState,
 )
 
+# Mark all tests in this module
+pytestmark = [pytest.mark.adapter, pytest.mark.aitrackdown, pytest.mark.unit]
+
 
 @pytest.fixture
 def adapter_config(aitrackdown_temp_dir: Path) -> dict[str, Any]:
@@ -63,7 +66,7 @@ class TestAITrackdownAdapterInit:
         mapping = aitrackdown_adapter._get_state_mapping()
 
         assert mapping[TicketState.OPEN] == "open"
-        assert mapping[TicketState.IN_PROGRESS] == "in-progress"
+        assert mapping[TicketState.IN_PROGRESS] == "in_progress"
         assert mapping[TicketState.READY] == "ready"
         assert mapping[TicketState.TESTED] == "tested"
         assert mapping[TicketState.DONE] == "done"
